.. pyrlp documentation master file, created by
   sphinx-quickstart on Mon Feb 16 14:20:49 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyrlp's documentation!
=================================

*pyrlp* is a package for encoding and decoding data to and from *recursive
length prefix encoding* (*RLP*). This format finds widely spread use in the
Ethereum world.

.. toctree::
   :maxdepth: 2

   quickstart
   tutorial
   api
   releases



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

